@@ -4,6 +4,8 @@ from django.contrib.admin.options import csrf_protect_m
 
 class DjangoTabbedChangeformAdmin(admin.ModelAdmin):
 
+    tabs = []
+
     class Media:
         css = {
             "all": [
@@ -20,7 +22,7 @@ class DjangoTabbedChangeformAdmin(admin.ModelAdmin):
     @csrf_protect_m
     def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
         extra_context = extra_context or {}
-        extra_context["tabs"] = self.get_tabs(request, object_id, form_url, extra_context)
+        extra_context["django_tabbed_changeform_admin_tabs"] = self.get_tabs(request, object_id, form_url, extra_context)
         return super().changeform_view(request, object_id, form_url, extra_context)
 
     def get_tabs(self, request, object_id, form_url, extra_context):
